summaryrefslogtreecommitdiffstats
path: root/unix/tclUnixTime.c
diff options
context:
space:
mode:
Diffstat (limited to 'unix/tclUnixTime.c')
-rw-r--r--unix/tclUnixTime.c8
1 files changed, 5 insertions, 3 deletions
diff --git a/unix/tclUnixTime.c b/unix/tclUnixTime.c
index 8047858..5107062 100644
--- a/unix/tclUnixTime.c
+++ b/unix/tclUnixTime.c
@@ -9,7 +9,7 @@
* See the file "license.terms" for information on usage and redistribution
* of this file, and for a DISCLAIMER OF ALL WARRANTIES.
*
- * RCS: @(#) $Id: tclUnixTime.c,v 1.12 2001/11/21 02:36:21 hobbs Exp $
+ * RCS: @(#) $Id: tclUnixTime.c,v 1.13 2002/05/29 00:19:39 hobbs Exp $
*/
#include "tclInt.h"
@@ -303,7 +303,8 @@ TclpGetDate(time, useGMT)
*
* TclpStrftime --
*
* On Unix, we can safely call the native strftime implementation.
*
* Results:
* The normal strftime result.
@@ -315,11 +316,12 @@ TclpGetDate(time, useGMT)
*/
size_t
-TclpStrftime(s, maxsize, format, t)
+TclpStrftime(s, maxsize, format, t, useGMT)
char *s;
size_t maxsize;
CONST char *format;
CONST struct tm *t;
+ int useGMT;
{
if (format[0] == '%' && format[1] == 'Q') {
/* Format as a stardate */
@@ -303,7 +303,8 @@ TclpGetDate(time, useGMT)
* TclpStrftime --
*
- * On Unix, we can safely call the native strftime implementation.
+ * On Unix, we can safely call the native strftime implementation,
+ * and also ignore the useGMT parameter.
*
* Results: